@@ -49,7 +49,7 @@ sub new {
 #   tbl  - Table ref
 #
 # Optional Arguments:
-#   no_cols - Don't append columns to list oustide of functions.
+#   no_cols - Don't append columns to list outside of functions.
 #
 # Returns:
 #   Column list for SELECT
@@ -71,7 +71,7 @@ sub make_row_checksum {
    # https://bugs.launchpad.net/percona-toolkit/+bug/1016131
    die "all columns are excluded by --columns or --ignore-columns"
       unless @{$cols->{select}};
-      
+
    # Prepend columns to query, resulting in "col1, col2, FUNC(..col1, col2...)",
    # unless caller says not to.  The only caller that says not to is
    # make_chunk_checksum() which uses this row checksum as part of a larger
@@ -80,7 +80,7 @@ sub make_row_checksum {
    my $query;
    if ( !$args{no_cols} ) {
       $query = join(', ',
-                  map { 
+                  map {
                      my $col = $_;
                      if ( $col =~ m/UNIX_TIMESTAMP/ ) {
                         # Alias col name back to itself else its name becomes
@@ -152,7 +152,7 @@ sub make_row_checksum {
 #   func      - Hash function name
 #   crc_width - CRC width
 #   crc_type  - CRC type
-# 
+#
 # Returns:
 #   Column list for SELECT
 sub make_chunk_checksum {
@@ -169,7 +169,7 @@ sub make_chunk_checksum {
    my $q     = $self->{Quoter};
 
    my %crc_args = $self->get_crc_args(%args);
-   PTDEBUG && _d("Checksum strat:", Dumper(\%crc_args));
+   PTDEBUG && _d('Checksum start:', Dumper(\%crc_args));
 
    # This checksum algorithm concatenates the columns in each row and
    # checksums them, then slices this checksum up into 16-character chunks.
@@ -257,7 +257,7 @@ sub get_crc_args {
    my $func      = $args{func}     || $self->_get_hash_func(%args);
    my $crc_width = $args{crc_width}|| $self->_get_crc_width(%args, func=>$func);
    my $crc_type  = $args{crc_type} || $self->_get_crc_type(%args, func=>$func);
-   my $opt_slice; 
+   my $opt_slice;
    if ( $args{dbh} && $crc_type !~ m/int$/ ) {
       $opt_slice = $self->_optimize_xor(%args, func=>$func);
    }
@@ -468,36 +468,36 @@ sub _make_xor_slices {
    return join(', ', @slices);
 }
 
-# Queries the replication table for chunks that differ from the master's data.
+# Queries the replication table for chunks that differ from the source's data.
 sub find_replication_differences {
    my ($self, %args) = @_;
-   my @required_args = qw(dbh repl_table);
+   my @required_args = qw(dbh repl_table source_crc_name source_cnt_name);
    foreach my $arg( @required_args ) {
       die "I need a $arg argument" unless $args{$arg};
    }
-   my ($dbh, $repl_table) = @args{@required_args};
+   my ($dbh, $repl_table, $source_crc_name, $source_cnt_name) = @args{@required_args};
 
-    
-   my $tries = $self->{'OptionParser'}->get('replicate-check-retries') || 1; 
+
+   my $tries = $self->{'OptionParser'}->get('replicate-check-retries') || 1;
    my $diffs;
    while ($tries--) {
       my $sql
          = "SELECT CONCAT(db, '.', tbl) AS `table`, "
          . "chunk, chunk_index, lower_boundary, upper_boundary, "
-         . "COALESCE(this_cnt-master_cnt, 0) AS cnt_diff, "
+         . "COALESCE(this_cnt-${source_cnt_name}, 0) AS cnt_diff, "
          . "COALESCE("
-         .   "this_crc <> master_crc OR ISNULL(master_crc) <> ISNULL(this_crc), 0"
-         . ") AS crc_diff, this_cnt, master_cnt, this_crc, master_crc "
+         .   "this_crc <> ${source_crc_name} OR ISNULL(${source_crc_name}) <> ISNULL(this_crc), 0"
+         . ") AS crc_diff, this_cnt, ${source_cnt_name}, this_crc, ${source_crc_name} "
          . "FROM $repl_table "
-         . "WHERE (master_cnt <> this_cnt OR master_crc <> this_crc "
-         .        "OR ISNULL(master_crc) <> ISNULL(this_crc)) "
+         . "WHERE (${source_cnt_name} <> this_cnt OR ${source_crc_name} <> this_crc "
+         .        "OR ISNULL(${source_crc_name}) <> ISNULL(this_crc)) "
          . ($args{where} ? " AND ($args{where})" : "");
       PTDEBUG && _d($sql);
       $diffs = $dbh->selectall_arrayref($sql, { Slice => {} });
       if (!@$diffs || !$tries) { # if no differences are found OR we are out of tries left...
          last;                   # get out now
       }
-      sleep 1;            
+      sleep 1;
    }
    return $diffs;
 }
