@@ -326,7 +326,7 @@ sub make_row_checksum {
    my $query;
    if ( !$args{no_cols} ) {
       $query = join(', ',
-                  map { 
+                  map {
                      my $col = $_;
                      if ( $col =~ m/\+ 0/ ) {
                         # Alias col name back to itself else its name becomes
@@ -469,20 +469,20 @@ sub make_checksum_query {
    return $result . "FROM /*DB_TBL*//*INDEX_HINT*//*WHERE*/";
 }
 
-# Queries the replication table for chunks that differ from the master's data.
+# Queries the replication table for chunks that differ from the source's data.
 sub find_replication_differences {
    my ( $self, $dbh, $table ) = @_;
 
    my $sql
       = "SELECT db, tbl, CONCAT(db, '.', tbl) AS `table`, "
       . "chunk, chunk_index, lower_boundary, upper_boundary, "
-      . "COALESCE(this_cnt-master_cnt, 0) AS cnt_diff, "
+      . "COALESCE(this_cnt-source_cnt, 0) AS cnt_diff, "
       . "COALESCE("
-      .   "this_crc <> master_crc OR ISNULL(master_crc) <> ISNULL(this_crc), 0"
-      . ") AS crc_diff, this_cnt, master_cnt, this_crc, master_crc "
+      .   "this_crc <> source_crc OR ISNULL(source_crc) <> ISNULL(this_crc), 0"
+      . ") AS crc_diff, this_cnt, source_cnt, this_crc, source_crc "
       . "FROM $table "
-      . "WHERE master_cnt <> this_cnt OR master_crc <> this_crc "
-      . "OR ISNULL(master_crc) <> ISNULL(this_crc)";
+      . "WHERE source_cnt <> this_cnt OR source_crc <> this_crc "
+      . "OR ISNULL(source_crc) <> ISNULL(this_crc)";
    PTDEBUG && _d($sql);
    my $diffs = $dbh->selectall_arrayref($sql, { Slice => {} });
    return $diffs;
